@@ -4,9 +4,11 @@ package UNIVERSAL::Object;
 use strict;
 use warnings;
 
+use 5.006;
+
 use Carp ();
 
-our $VERSION   = '0.06';
+our $VERSION   = '0.07';
 our $AUTHORITY = 'cpan:STEVAN';
 
 BEGIN {
@@ -113,7 +115,7 @@ UNIVERSAL::Object - A useful base class
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -313,13 +315,21 @@ by C<DESTROY>.
 The sole function of this method is to kick off the call to all the
 C<DEMOLISH> methods during destruction.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<UNIVERSAL::Object::Immutable>
+
+=back
+
 =head1 AUTHOR
 
 Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Stevan Little.
+This software is copyright (c) 2016, 2017 by Stevan Little.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
